@@ -162,6 +162,7 @@ bool        r_damageeffect = r_damageeffect_default;
 int         r_detail = r_detail_default;
 bool        r_diskicon = r_diskicon_default;
 bool        r_ditheredlighting = r_ditheredlighting_default;
+int         r_extralighting = r_extralighting_default;
 bool        r_fixmaperrors = r_fixmaperrors_default;
 bool        r_fixspriteoffsets = r_fixspriteoffsets_default;
 bool        r_floatbob = r_floatbob_default;
@@ -171,7 +172,6 @@ bool        r_graduallighting = r_graduallighting_default;
 bool        r_homindicator = r_homindicator_default;
 bool        r_hud = r_hud_default;
 bool        r_hud_translucency = r_hud_translucency_default;
-int         r_levelbrightness = r_levelbrightness_default;
 bool        r_linearskies = r_linearskies_default;
 bool        r_liquid_bob = r_liquid_bob_default;
 bool        r_liquid_bobsprites = r_liquid_bobsprites_default;
@@ -351,7 +351,7 @@ static default_t cvars[] =
     CVAR_BOOL         (autotilt,                         autotilt,                              autotilt,                              BOOLVALUEALIAS      ),
     CVAR_BOOL         (autouse,                          autouse,                               autouse,                               BOOLVALUEALIAS      ),
     CVAR_BOOL         (centerweapon,                     centreweapon,                          centerweapon,                          BOOLVALUEALIAS      ),
-    CVAR_INT          (con_edgecolor,                    con_edgecolor,                         con_edgecolor,                         EDGECOLORVALUEALIAS),
+    CVAR_INT          (con_edgecolor,                    con_edgecolour,                        con_edgecolor,                         EDGECOLORVALUEALIAS),
     CVAR_INT          (con_timestampformat,              con_timestampformat,                   con_timestampformat,                   TIMESTAMPVALUEALIAS),
     CVAR_BOOL         (con_timestamps,                   con_timestamps,                        con_timestamps,                        BOOLVALUEALIAS      ),
     CVAR_INT          (con_warninglevel,                 con_warninglevel,                      con_warninglevel,                      NOVALUEALIAS        ),
@@ -417,6 +417,7 @@ static default_t cvars[] =
     CVAR_INT          (r_detail,                         r_detail,                              r_detail,                              DETAILVALUEALIAS    ),
     CVAR_BOOL         (r_diskicon,                       r_diskicon,                            r_diskicon,                            BOOLVALUEALIAS      ),
     CVAR_BOOL         (r_ditheredlighting,               r_ditheredlighting,                    r_ditheredlighting,                    BOOLVALUEALIAS      ),
+    CVAR_INT_PERCENT  (r_extralighting,                  r_levelbrightness,                     r_extralighting,                       NOVALUEALIAS        ),
     CVAR_BOOL         (r_fixmaperrors,                   r_fixmaperrors,                        r_fixmaperrors,                        BOOLVALUEALIAS      ),
     CVAR_BOOL         (r_fixspriteoffsets,               r_fixspriteoffsets,                    r_fixspriteoffsets,                    BOOLVALUEALIAS      ),
     CVAR_BOOL         (r_floatbob,                       r_floatbob,                            r_floatbob,                            BOOLVALUEALIAS      ),
@@ -426,7 +427,6 @@ static default_t cvars[] =
     CVAR_BOOL         (r_homindicator,                   r_homindicator,                        r_homindicator,                        BOOLVALUEALIAS      ),
     CVAR_BOOL         (r_hud,                            r_hud,                                 r_hud,                                 BOOLVALUEALIAS      ),
     CVAR_BOOL         (r_hud_translucency,               r_hud_translucency,                    r_hud_translucency,                    BOOLVALUEALIAS      ),
-    CVAR_INT_PERCENT  (r_levelbrightness,                r_levelbrightness,                     r_levelbrightness,                     NOVALUEALIAS        ),
     CVAR_BOOL         (r_linearskies,                    r_linearskies,                         r_linearskies,                         BOOLVALUEALIAS      ),
     CVAR_BOOL         (r_liquid_bob,                     r_liquid_bob,                          r_liquid_bob,                          BOOLVALUEALIAS      ),
     CVAR_BOOL         (r_liquid_bobsprites,              r_liquid_bobsprites,                   r_liquid_bobsprites,                   BOOLVALUEALIAS      ),
