@@ -1259,10 +1259,8 @@ bool P_TakeSpecialThing(const mobjtype_t type)
     {
         // green armor
         case MT_MISC0:
-            if (viewplayer->armortype != green_armor_class)
-                return false;
-
-            if (viewplayer->armor < green_armor_class * 100)
+            if (viewplayer->armortype != green_armor_class
+                || viewplayer->armor < green_armor_class * 100)
                 return false;
 
             viewplayer->armor -= green_armor_class * 100;
@@ -1272,10 +1270,8 @@ bool P_TakeSpecialThing(const mobjtype_t type)
 
         // blue armor
         case MT_MISC1:
-            if (viewplayer->armortype != blue_armor_class)
-                return false;
-
-            if (viewplayer->armor < blue_armor_class * 100)
+            if (viewplayer->armortype != blue_armor_class
+                || viewplayer->armor < blue_armor_class * 100)
                 return false;
 
             viewplayer->armor -= blue_armor_class * 100;
@@ -1285,16 +1281,10 @@ bool P_TakeSpecialThing(const mobjtype_t type)
 
         // bonus health
         case MT_MISC2:
-            if (viewplayer->cheats & CF_GODMODE)
-                return false;
-
-            if (viewplayer->powers[pw_invulnerability])
-                return false;
-
-            if ((viewplayer->cheats & CF_BUDDHA) && viewplayer->health == 1)
-                return false;
-
-            if (viewplayer->health <= 0)
+            if ((viewplayer->cheats & CF_GODMODE)
+                || viewplayer->powers[pw_invulnerability]
+                || ((viewplayer->cheats & CF_BUDDHA) && viewplayer->health == 1)
+                || viewplayer->health <= 0)
                 return false;
 
             viewplayer->health--;
@@ -1315,16 +1305,10 @@ bool P_TakeSpecialThing(const mobjtype_t type)
 
         // soulsphere
         case MT_MISC12:
-            if (viewplayer->cheats & CF_GODMODE)
-                return false;
-
-            if (viewplayer->powers[pw_invulnerability])
-                return false;
-
-            if ((viewplayer->cheats & CF_BUDDHA) && viewplayer->health <= soul_health)
-                return false;
-
-            if (viewplayer->health < soul_health)
+            if ((viewplayer->cheats & CF_GODMODE)
+                || viewplayer->powers[pw_invulnerability]
+                || ((viewplayer->cheats & CF_BUDDHA) && viewplayer->health <= soul_health)
+                || viewplayer->health < soul_health)
                 return false;
 
             viewplayer->health -= soul_health;
@@ -1337,16 +1321,10 @@ bool P_TakeSpecialThing(const mobjtype_t type)
 
         // mega health
         case MT_MEGA:
-            if (viewplayer->cheats & CF_GODMODE)
-                return false;
-
-            if (viewplayer->powers[pw_invulnerability])
-                return false;
-
-            if ((viewplayer->cheats & CF_BUDDHA) && viewplayer->health <= mega_health)
-                return false;
-
-            if (viewplayer->health < mega_health)
+            if ((viewplayer->cheats & CF_GODMODE)
+                || viewplayer->powers[pw_invulnerability]
+                || ((viewplayer->cheats & CF_BUDDHA) && viewplayer->health <= mega_health)
+                || viewplayer->health < mega_health)
                 return false;
 
             viewplayer->health -= mega_health;
@@ -1419,16 +1397,10 @@ bool P_TakeSpecialThing(const mobjtype_t type)
 
         // stimpack
         case MT_MISC10:
-            if ((viewplayer->cheats & CF_GODMODE))
-                return false;
-
-            if (viewplayer->powers[pw_invulnerability])
-                return false;
-
-            if ((viewplayer->cheats & CF_BUDDHA) && viewplayer->health <= STIMPACKHEALTH)
-                return false;
-
-            if (viewplayer->health < STIMPACKHEALTH)
+            if ((viewplayer->cheats & CF_GODMODE)
+                || viewplayer->powers[pw_invulnerability]
+                || ((viewplayer->cheats & CF_BUDDHA) && viewplayer->health <= STIMPACKHEALTH)
+                || viewplayer->health < STIMPACKHEALTH)
                 return false;
 
             viewplayer->health -= STIMPACKHEALTH;
@@ -1441,16 +1413,10 @@ bool P_TakeSpecialThing(const mobjtype_t type)
 
         // medikit
         case MT_MISC11:
-            if (viewplayer->cheats & CF_GODMODE)
-                return false;
-
-            if (viewplayer->powers[pw_invulnerability])
-                return false;
-
-            if ((viewplayer->cheats & CF_BUDDHA) && viewplayer->health <= MEDIKITHEALTH)
-                return false;
-
-            if (viewplayer->health < MEDIKITHEALTH)
+            if ((viewplayer->cheats & CF_GODMODE)
+                || viewplayer->powers[pw_invulnerability]
+                || ((viewplayer->cheats & CF_BUDDHA) && viewplayer->health <= MEDIKITHEALTH)
+                || viewplayer->health < MEDIKITHEALTH)
                 return false;
 
             viewplayer->health -= MEDIKITHEALTH;
@@ -1607,7 +1573,7 @@ static void P_WriteObituary(mobj_t *target, mobj_t *inflicter, mobj_t *source, c
                 const bool  friendly = (source->flags & MF_FRIEND);
 
                 M_snprintf(sourcename, sizeof(sourcename), "%s %s%s",
-                    (friendly && source->type < NUMMOBJTYPES && monstercount[source->type] == 1 ? "the" :
+                    (friendly && source->type > MT_NULL && source->type < NUMMOBJTYPES && monstercount[source->type] == 1 ? "the" :
                         (*source->info->name1 && isvowel(source->info->name1[0]) && !friendly ? "an" : "a")),
                     (friendly ? "friendly " : ""),
                     (*source->info->name1 && !M_StringStartsWith(source->info->name1, "Deh_Actor_") ? source->info->name1 : "monster"));
@@ -1629,7 +1595,7 @@ static void P_WriteObituary(mobj_t *target, mobj_t *inflicter, mobj_t *source, c
                 const bool  friendly = (target->flags & MF_FRIEND);
 
                 M_snprintf(targetname, sizeof(targetname), "%s %s%s",
-                    (friendly && target->type < NUMMOBJTYPES && monstercount[target->type] == 1 ? "the" :
+                    (friendly && target->type > MT_NULL && target->type < NUMMOBJTYPES && monstercount[target->type] == 1 ? "the" :
                         (*target->info->name1 && isvowel(target->info->name1[0]) && !friendly ? "an" : "a")),
                     (friendly ? "friendly " : ""),
                     (*target->info->name1 && !M_StringStartsWith(target->info->name1, "Deh_Actor_") ? target->info->name1 : "monster"));
@@ -1650,7 +1616,7 @@ static void P_WriteObituary(mobj_t *target, mobj_t *inflicter, mobj_t *source, c
                 const bool  friendly = (source->flags & MF_FRIEND);
 
                 M_snprintf(sourcename, sizeof(sourcename), "%s %s%s",
-                    (friendly && source->type < NUMMOBJTYPES && monstercount[source->type] == 1 ? "the" :
+                    (friendly && source->type > MT_NULL && source->type < NUMMOBJTYPES && monstercount[source->type] == 1 ? "the" :
                         (*source->info->name1 && isvowel(source->info->name1[0]) && !friendly ? "an" : "a")),
                     (friendly ? "friendly " : ""),
                     (*source->info->name1 && !M_StringStartsWith(source->info->name1, "Deh_Actor_") ? source->info->name1 : "monster"));
@@ -1733,7 +1699,7 @@ static void P_WriteObituary(mobj_t *target, mobj_t *inflicter, mobj_t *source, c
                     const bool  corpse = ((target->flags & MF_CORPSE) && source != target);
 
                     M_snprintf(targetname, sizeof(targetname), "%s %s%s",
-                        (friendly && target->type < NUMMOBJTYPES && monstercount[target->type] == 1 ? "the" :
+                        (friendly && target->type > MT_NULL && target->type < NUMMOBJTYPES && monstercount[target->type] == 1 ? "the" :
                             (*target->info->name1 && isvowel(target->info->name1[0]) && !corpse && !friendly ? "an" : "a")),
                         (corpse && !M_StringStartsWith(target->info->name1, "dead ") ? "dead " : (friendly ? "friendly " : "")),
                         (*target->info->name1 && !M_StringStartsWith(target->info->name1, "Deh_Actor_") ? target->info->name1 : "monster"));
@@ -1807,7 +1773,7 @@ static void P_WriteObituary(mobj_t *target, mobj_t *inflicter, mobj_t *source, c
                         const bool  friendly = (target->flags & MF_FRIEND);
 
                         M_snprintf(targetname, sizeof(targetname), "%s %s%s",
-                            (friendly && target->type < NUMMOBJTYPES && monstercount[target->type] == 1 ? "the" :
+                            (friendly && target->type > MT_NULL && target->type < NUMMOBJTYPES && monstercount[target->type] == 1 ? "the" :
                                 (*target->info->name1 && isvowel(target->info->name1[0]) && !friendly ? "an" : "a")),
                             (friendly ? "friendly " : ""),
                             (*target->info->name1 && !M_StringStartsWith(target->info->name1, "Deh_Actor_") ? target->info->name1 : "monster"));
@@ -1855,7 +1821,7 @@ static void P_WriteObituary(mobj_t *target, mobj_t *inflicter, mobj_t *source, c
                         const bool  corpse = (target->flags & MF_CORPSE);
 
                         M_snprintf(targetname, sizeof(targetname), "%s %s%s",
-                            (friendly && target->type < NUMMOBJTYPES && monstercount[target->type] == 1 ? "the" :
+                            (friendly && target->type > MT_NULL && target->type < NUMMOBJTYPES && monstercount[target->type] == 1 ? "the" :
                                 (*target->info->name1 && isvowel(target->info->name1[0]) && !corpse && !friendly ? "an" : "a")),
                             (corpse && !M_StringStartsWith(target->info->name1, "dead ") ? "dead " : (friendly ? "friendly " : "")),
                             (*target->info->name1 && !M_StringStartsWith(target->info->name1, "Deh_Actor_") ? target->info->name1 : "monster"));
@@ -1892,7 +1858,7 @@ static void P_WriteObituary(mobj_t *target, mobj_t *inflicter, mobj_t *source, c
                 const bool  friendly = (source->flags & MF_FRIEND);
 
                 M_snprintf(sourcename, sizeof(sourcename), "%s %s%s",
-                    (friendly && source->type < NUMMOBJTYPES && monstercount[source->type] == 1 ? "the" :
+                    (friendly && source->type > MT_NULL && source->type < NUMMOBJTYPES && monstercount[source->type] == 1 ? "the" :
                         (*source->info->name1 && isvowel(source->info->name1[0]) && !friendly ? "an" : "a")),
                     (friendly ? "friendly " : ""),
                     (*source->info->name1 && !M_StringStartsWith(source->info->name1, "Deh_Actor_") ? source->info->name1 : "monster"));
@@ -1920,7 +1886,7 @@ static void P_WriteObituary(mobj_t *target, mobj_t *inflicter, mobj_t *source, c
 
                     M_snprintf(targetname, sizeof(targetname), "%s %s%s",
                         (source->type == target->type || M_StringCompare(source->info->name1, target->info->name1) ? "another" :
-                            (friendly && target->type < NUMMOBJTYPES && monstercount[target->type] == 1 ? "the" :
+                            (friendly && target->type > MT_NULL && target->type < NUMMOBJTYPES && monstercount[target->type] == 1 ? "the" :
                             (*target->info->name1 && isvowel(target->info->name1[0]) && !friendly ? "an" : "a"))),
                         (friendly ? "friendly " : ""),
                         (*target->info->name1 && !M_StringStartsWith(target->info->name1, "Deh_Actor_") ? target->info->name1 : "monster"));
@@ -1994,7 +1960,10 @@ static void P_SpawnGibBlood(mobj_t *target)
             mo->momx = M_BigRandomInt(2, 8) * FRACUNIT;
             mo->momy = M_BigRandomInt(-8, 8) * FRACUNIT;
             mo->momz = M_BigRandomInt(-8, 8) * FRACUNIT;
-            mo->flags2 |= (M_BigRandom() & 1) * MF2_MIRRORED;
+
+            if (M_BigRandom() & 1)
+                mo->flags2 |= MF2_MIRRORED;
+
             mo->colfunc = bloodcolfunc;
             mo->altcolfunc = bloodcolfunc;
             mo->bloodcolor = target->bloodcolor;
@@ -2050,7 +2019,7 @@ void P_KillMobj(mobj_t *target, mobj_t *inflicter, mobj_t *source, const bool te
         {
             stat_monsterskilled_total = SafeAdd(stat_monsterskilled_total, 1);
 
-            if (type < NUMMOBJTYPES)
+            if (type > MT_NULL && type < NUMMOBJTYPES)
             {
                 viewplayer->monsterskilled[type]++;
                 stat_monsterskilled[type] = SafeAdd(stat_monsterskilled[type], 1);
@@ -2487,7 +2456,7 @@ void P_ResurrectMobj(mobj_t *target)
     viewplayer->resurrectioncount++;
     stat_monstersresurrected = SafeAdd(stat_monstersresurrected, 1);
 
-    if (type < NUMMOBJTYPES)
+    if (type > MT_NULL && type < NUMMOBJTYPES)
         stat_monsterskilled[type] = SafeAdd(stat_monsterskilled[type], -1);
 
     P_UpdateThinker(&target->thinker);
