@@ -667,7 +667,7 @@ static void P_NightmareRespawn(mobj_t *mobj)
 
     if (obituaries)
         C_PlayerMessage("%s dead%s%s has respawned.",
-            ((mo->flags & MF_FRIEND) && mo->type < NUMMOBJTYPES && monstercount[mo->type] == 1 ? "The" : "A"),
+            ((mo->flags & MF_FRIEND) && mo->type > MT_NULL && mo->type < NUMMOBJTYPES && monstercount[mo->type] == 1 ? "The" : "A"),
             ((mo->flags & MF_FRIEND) ? ", friendly " : " "),
             (*mo->info->name1 ? mo->info->name1 : "monster"));
 
@@ -1101,7 +1101,7 @@ static void P_SpawnPlayer(const mapthing_t *mthing)
     viewplayer->mo->momx = 0;
     viewplayer->mo->momy = 0;
     viewplayer->mo->bloodsplats = CORPSEBLOODSPLATS;
-    viewplayer->mo->floatbob = (M_BigRandom() & 63);
+    viewplayer->mo->floatbob = (M_BigRandom() & (ANIMATEDLIQUIDDIFFS - 1));
     viewplayer->momx = 0;
     viewplayer->momy = 0;
     viewplayer->lookdir = 0;
@@ -1324,7 +1324,7 @@ mobj_t *P_SpawnMapThing(mapthing_t *mthing, const bool spawnmonsters)
         if (!((mobjinfo[i].flags ^ MF_COUNTKILL) & (MF_FRIEND | MF_COUNTKILL)))
             totalkills++;
 
-        if (i < NUMMOBJTYPES)
+        if (i > MT_NULL && i < NUMMOBJTYPES)
             monstercount[i]++;
     }
 
@@ -1432,7 +1432,7 @@ mobj_t *P_SpawnMapThing(mapthing_t *mthing, const bool spawnmonsters)
             mobj->floatbob = prevthingbob;
         else
         {
-            mobj->floatbob = (M_BigRandom() & 63);
+            mobj->floatbob = (M_BigRandom() & (ANIMATEDLIQUIDDIFFS - 1));
 
             prevthingbob = mobj->floatbob;
             prevthingx = x;
