@@ -1101,7 +1101,7 @@ static void R_SetupFrame(void)
     {
         const uint64_t  time = I_GetTimeMS();
 
-        if (shake > time)
+        if (shake > time && shakeduration)
         {
             const fixed_t   amount = FRACUNIT * (fixed_t)(shake - time) / shakeduration;
 
@@ -1119,7 +1119,7 @@ static void R_SetupFrame(void)
     if (pitch)
         centery += pitch * 2 * (r_screensize + 3) / 10;
 
-    extralight = (viewplayer->extralight << 2) + r_levelbrightness / 3;
+    extralight = (viewplayer->extralight << 2) + r_extralighting / 3;
 
     centeryfrac = centery << FRACBITS;
     yslope = yslopes[LOOKDIRMAX + pitch];
@@ -1191,12 +1191,10 @@ void R_RenderPlayerView(void)
 
     if (r_homindicator)
         V_FillRect(0, viewwindowx, viewwindowy, viewwidth, viewheight,
-            (maptime % 20 < 9 ? nearestred : (viewplayer->fixedcolormap == INVERSECOLORMAP ?
-                colormaps[0][32 * 256 + WHITE] : nearestblack)), 0, false, false, NULL, NULL);
+            (maptime % 20 < 9 ? nearestred : nearestblack), 0, false, false, NULL, NULL);
     else if ((viewplayer->cheats & CF_NOCLIP) || freeze)
         V_FillRect(0, viewwindowx, viewwindowy, viewwidth, viewheight,
-            (viewplayer->fixedcolormap == INVERSECOLORMAP ? colormaps[0][32 * 256 + WHITE] : nearestblack),
-            0, false, false, NULL, NULL);
+            nearestblack, 0, false, false, NULL, NULL);
 
     R_RenderBSPNode(numnodes - 1);  // head node is the last node output
 
