@@ -412,11 +412,11 @@ void R_InitDistortedFlats(void)
                 int sinvalue, sinvalue2;
                 int x1, y1;
 
-                sinvalue = finesine[((y * SWIRLFACTOR + i * 5 + 900) & FINEMASK)] * 2;
-                sinvalue2 = finesine[((x * SWIRLFACTOR2 + i * 4 + 300) & FINEMASK)] * 2;
+                sinvalue = finesine[(y * SWIRLFACTOR + i * 5 + 900) & FINEMASK] * 2;
+                sinvalue2 = finesine[(x * SWIRLFACTOR2 + i * 4 + 300) & FINEMASK] * 2;
                 x1 = x + 128 + (sinvalue >> FRACBITS) + (sinvalue2 >> FRACBITS);
-                sinvalue = finesine[((x * SWIRLFACTOR + i * 3 + 700) & FINEMASK)] * 2;
-                sinvalue2 = finesine[((y * SWIRLFACTOR2 + i * 4 + 1200) & FINEMASK)] * 2;
+                sinvalue = finesine[(x * SWIRLFACTOR + i * 3 + 700) & FINEMASK] * 2;
+                sinvalue2 = finesine[(y * SWIRLFACTOR2 + i * 4 + 1200) & FINEMASK] * 2;
                 y1 = y + 128 + (sinvalue >> FRACBITS) + (sinvalue2 >> FRACBITS);
 
                 offset[(y << 6) + x] = ((y1 & 63) << 6) + (x1 & 63);
